/*
 * Copyright (C) 2004 emuWorks
 * http://games.technoplaza.net
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <wx/wxprec.h>

#ifndef WX_PRECOMP
   #include <wx/wx.h>
#endif
 
#include "chtframe.hh"
#include "../chtdecoder.hh"
#include "../datastructures/chtcode.hh"

BEGIN_EVENT_TABLE(CHTFrame, wxFrame)
    EVT_MENU(IDM_FILE_OPEN, CHTFrame::OnOpen)
    EVT_MENU(IDM_FILE_SAVE, CHTFrame::OnSave)
    EVT_MENU(IDM_FILE_EXIT, CHTFrame::OnExit)
    EVT_MENU(IDM_HELP_ABOUT, CHTFrame::OnAbout)
END_EVENT_TABLE()

CHTFrame::CHTFrame(const wxString& title, const wxPoint& pos,
                   const wxSize& size) : wxFrame((wxFrame *)NULL, -1,
                   title, pos, size) {
    // build the main menu
    menuBar = new wxMenuBar();
    fileMenu = new wxMenu();
    helpMenu = new wxMenu();
    
    fileMenu->Append(IDM_FILE_OPEN, "&Open", "Open .CHT File for Decoding");
    fileMenu->Append(IDM_FILE_SAVE, "&Save", "Save decode .CHT codes to file");
    fileMenu->AppendSeparator();
    fileMenu->Append(IDM_FILE_EXIT, "E&xit", "Exit " + *CHTDecoder::APP_NAME);
    
    // disable saving till one is loaded
    fileMenu->Enable(IDM_FILE_SAVE, false);
    
    helpMenu->Append(IDM_HELP_ABOUT, 
                     "&About " + *CHTDecoder::APP_NAME + "...",
                     "Display Copyright Information");
    
    menuBar->Append(fileMenu, "&File");
    menuBar->Append(helpMenu, "&Help");
    
    SetMenuBar(menuBar);
    
    // build the status bar
    CreateStatusBar();
    SetStatusText(*CHTDecoder::APP_NAME + ' ' + *CHTDecoder::APP_VERSION);
    
    // build the text control
    chtText = new CHTTextControl(this);
    
    // build the file dialog
    fileDialog = new wxFileDialog(this);
}

void CHTFrame::OnOpen(wxCommandEvent& event) {
    static wxString title("Choose a .CHT file to decode...");
    static wxString wildcard("ZSNES .CHT files (*.cht)|*.cht");
    
    fileDialog->SetStyle(wxOPEN | wxCHANGE_DIR);
    fileDialog->SetMessage(title);
    fileDialog->SetWildcard(wildcard);
    
    int value = fileDialog->ShowModal();
    
    if (value == wxID_OK) {
        wxString filename = fileDialog->GetFilename();
        chtText->readCHTFile(filename);
    }
}

void CHTFrame::OnSave(wxCommandEvent& event) {
    static wxString title("Choose a .TXT file to save to...");
    static wxString wildcard("Text files (*.txt)|*.txt");
    
    fileDialog->SetStyle(wxSAVE | wxCHANGE_DIR);
    fileDialog->SetMessage(title);
    fileDialog->SetWildcard(wildcard);
    
    int value = fileDialog->ShowModal();
    
    if (value == wxID_OK) {
        wxString filename = fileDialog->GetFilename();
        chtText->SaveFile(filename);
    }
}

void CHTFrame::OnExit(wxCommandEvent& event) {
    Close(true);
}

void CHTFrame::OnAbout(wxCommandEvent &event) {
    wxMessageDialog dlg(this, *CHTDecoder::APP_NAME + ' ' + 
                        *CHTDecoder::APP_VERSION + '\n' +
                        *CHTDecoder::APP_COPYRIGHT, "About " + 
                        *CHTDecoder::APP_NAME + "...",
                        wxOK | wxICON_INFORMATION);
    dlg.ShowModal();
}

